@@ -37,7 +37,7 @@ def analyze_turnpoints(improved_dlc_dir, output_dir):
     while True:
 
         if 'Darwin' in platform():
-            p = Popen(['open', f'{output_dir}/plot_turnpoints.r'])
+            Popen(['open', f'{output_dir}/plot_turnpoints.r'])
         else:
             pass
 
@@ -82,8 +82,6 @@ def analyze_turnpoints(improved_dlc_dir, output_dir):
 
             df = df.drop(columns=['proba'])
 
-            k, j, t = 300, 180, 120
-
             for i in times:
                 if i < tt[0]:
                     tls.append('FT')
@@ -158,8 +156,6 @@ def analyze_turnpoints(improved_dlc_dir, output_dir):
 
             files = glob(f'{output_dir_super}/*.csv')
 
-            tls = trials()
-
             for file in files:
 
                 df = pd.read_csv(file)
@@ -172,9 +168,9 @@ def analyze_turnpoints(improved_dlc_dir, output_dir):
                 def altE(l):
                     if firstispeak == 'False':
                         return l[::2]
-
-                    elif firstispeak == 'True':
+                    if firstispeak == 'True':
                         return l[1::2]
+                    return None
 
                 ls = df[variable].tolist()
 
@@ -190,20 +186,18 @@ def analyze_turnpoints(improved_dlc_dir, output_dir):
 
                     if i == n - 1:
                         break
+                    if variable == 'time':
+                        diff.append(altE(ls)[i + 1] - altE(ls)[i])
+                        trial.append(altE(df['trial'].tolist()))
+                        diff_calc.append(
+                            f'({altE(ls)[i + 1]}) - ({altE(ls)[i]})')
 
-                    else:
-                        if variable == 'time':
-                            diff.append(altE(ls)[i + 1] - altE(ls)[i])
-                            trial.append(altE(df['trial'].tolist()))
-                            diff_calc.append(
-                                f'({altE(ls)[i + 1]}) - ({altE(ls)[i]})')
-
-                        elif variable == 'velocity_value':
-                            diff.append(ls[1::2][i] - ls[::2][i])
-                            tl = df['trial'].tolist()
-                            trial.append(tl[::2])
-                            diff_calc.append(
-                                f'({round(ls[1::2][i], 4)}) - ({round(ls[::2][i], 4)})')
+                    elif variable == 'velocity_value':
+                        diff.append(ls[1::2][i] - ls[::2][i])
+                        tl = df['trial'].tolist()
+                        trial.append(tl[::2])
+                        diff_calc.append(
+                            f'({round(ls[1::2][i], 4)}) - ({round(ls[::2][i], 4)})')
 
                 diff = [round(x, 4) for x in diff]
 
